@@ -1541,7 +1541,11 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
   FT_UInt size;
 
 
+  /* XXX: right now, we abuse this flag to control */
+  /*      the global behaviour of the auto-hinter */
   load_flags = font->fallback_script << 30;
+  if (font->increase_x_height)
+    load_flags |= 1 << 29;
   if (!font->pre_hinting)
     load_flags |= FT_LOAD_NO_SCALE;
 
@@ -1562,6 +1566,10 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
 
   hints = &font->loader->hints;
 
+  /* do nothing if the setup delivered the dummy module only */
+  if (!hints->num_points)
+    return FT_Err_Ok;
+
   /* we allocate a buffer which is certainly large enough */
   /* to hold all of the created bytecode instructions; */
   /* later on it gets reallocated to its real size */
@@ -1623,7 +1631,19 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
   /* to find hints records which get pushed onto the bytecode stack */
 
 #ifdef DEBUGGING
-  printf("glyph %ld\n", idx);
+  {
+    int num_chars, i;
+
+
+    num_chars = fprintf(stderr, "glyph %ld\n", idx);
+    for (i = 0; i < num_chars - 1; i++)
+      putc('=', stderr);
+    fprintf(stderr, "\n\n");
+
+    ta_glyph_hints_dump_edges(_ta_debug_hints);
+    ta_glyph_hints_dump_segments(_ta_debug_hints);
+    ta_glyph_hints_dump_points(_ta_debug_hints);
+  }
 #endif
 
   /* we temporarily use `ins_buf' to record the current glyph hints, */
@@ -1663,10 +1683,10 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
     {
 #ifdef DEBUGGING
       {
-        printf("  %d:\n", size);
+        fprintf(stderr, "  %d:\n", size);
         for (p = bufp; p < recorder.hints_record.buf; p += 2)
-          printf(" %2d", *p * 256 + *(p + 1));
-        printf("\n");
+          fprintf(stderr, " %2d", *p * 256 + *(p + 1));
+        fprintf(stderr, "\n");
       }
 #endif
 
