@@ -23,6 +23,12 @@ extern "C" {
 #endif
 
 
+/* Some default values. */
+
+#define TA_HINTING_RANGE_MIN 8
+#define TA_HINTING_RANGE_MAX 1000
+#define TA_HINTING_LIMIT 1000
+
 /* Error type. */
 
 typedef int TA_Error;
@@ -118,15 +124,25 @@ typedef int
  *                                change the returned value.
  *
  *   hinting-range-min            An integer (which must be larger than or
- *                                equal to 2) giving the lowest ppem value
+ *                                equal to 2) giving the lowest PPEM value
  *                                used for autohinting.  If this field is
- *                                not set, it defaults to value 8.
+ *                                not set, it defaults to
+ *                                TA_HINTING_RANGE_MIN.
  *
  *   hinting-range-max            An integer (which must be larger than or
  *                                equal to the value of `hinting-range-min')
- *                                giving the highest ppem value used for
+ *                                giving the highest PPEM value used for
  *                                autohinting.  If this field is not set, it
- *                                defaults to value 1000.
+ *                                defaults to TA_HINTING_RANGE_MAX.
+ *
+ *   hinting-limit                An integer (which must be larger than or
+ *                                equal to the value of `hinting-range-max')
+ *                                which gives the largest PPEM value at
+ *                                which hinting is applied.  For larger
+ *                                values, hinting is switched off.  If this
+ *                                field is not set, it defaults to
+ *                                TA_HINTING_LIMIT.  If it is set to 0, no
+ *                                hinting limit is added to the bytecode.
  *
  *   pre-hinting                  An integer (1 for `on' and 0 for `off',
  *                                which is the default) to specify whether
@@ -137,14 +153,27 @@ typedef int
  *                                for most fonts this is 2048ppem.  Use this
  *                                if the hints move or scale subglyphs
  *                                independently of the output resolution.
- *                                Not implemented yet.
+ *
+ *   no-info                      If this integer is set to 1, no
+ *                                information about the parameters used to
+ *                                create the output font are added to the
+ *                                `Version' string (name ID 5) in the `name'
+ *                                table.  Default is value 0.
+ *
+ *   increase-x-height            An integer (1 for `on' and 0 for `off',
+ *                                which is the default).  For PPEM values in
+ *                                the range 5 < PPEM < 15, round up the
+ *                                font's x height much more often than
+ *                                normally if this flag is set.  Use this if
+ *                                holes in letters like `e' get filled, for
+ *                                example.
  *
  *   x-height-snapping-exceptions A pointer of type `const char*' to a
  *                                null-terminated string which gives a list
- *                                of comma separated ppem values or value
+ *                                of comma separated PPEM values or value
  *                                ranges at which no x-height snapping shall
  *                                be applied.  A value range has the form
- *                                `value1-value2', meaning `value1' <= ppem
+ *                                `value1-value2', meaning `value1' <= PPEM
  *                                <= `value2'.  Whitespace is not
  *                                significant; a trailing comma is ignored.
  *                                If the supplied argument is NULL, no
@@ -159,7 +188,8 @@ typedef int
  *                                the font's legal owner.  In case you have
  *                                such a permission you might set the
  *                                integer argument to value 1 to make
- *                                ttfautohint handle the font.
+ *                                ttfautohint handle the font.  The default
+ *                                value is 0.
  *
  *   fallback-script              An integer which specifies the default
  *                                script for glyphs not in the `latin'
@@ -174,13 +204,19 @@ typedef int
  *   All other options are optional.
  *
  * o `hinting-range-min' and `hinting-range-max' specify the range for which
- *   the autohinter generates optimized hinting code.  If a ppem is smaller
- *   than the value of `hinting-range-min', hinting still takes place but
- *   the configuration created for `hinting-range-min' is used.  The
- *   analogous action is taken for `hinting-range-max'.  The font's `gasp'
- *   table is set up to always use grayscale rendering with grid-fitting for
- *   standard hinting, and symmetric grid-fitting and symmetric smoothing
- *   for horizontal subpixel hinting (ClearType).
+ *   the autohinter generates optimized hinting code.  If a PPEM value is
+ *   smaller than the value of `hinting-range-min', hinting still takes
+ *   place but the configuration created for `hinting-range-min' is used.
+ *   The analogous action is taken for `hinting-range-max', only limited by
+ *   the value given with `hinting-limit'.  The font's `gasp' table is set
+ *   up to always use grayscale rendering with grid-fitting for standard
+ *   hinting, and symmetric grid-fitting and symmetric smoothing for
+ *   horizontal subpixel hinting (ClearType).
+ *
+ * o ttfautohint can't process a font a second time (well, it can, if the
+ *   font doesn't contain composite glyphs).  Just think of ttfautohint as
+ *   being a compiler, a tool which also can't process its created output
+ *   again.
  */
 
 TA_Error
